﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Stimulsoft.Report;
using Merkur.Data;
using Merkur.WPFReports;
using Stimulsoft.Report.Engine;

namespace NotFilledDataBand
{
    /// <summary>
    /// Interaktionslogik für MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            StiReport report = new StiReport();
            byte[] reportStr = GetReportDefinition();//In the real App it will be loaded by an WCF-Service with given vars to load Data from the Database

            report.LoadPackedReport(reportStr);
            report.RenderWithWpf(true);

            viewerControl.Report = report;
        }

        //From this point on we are on the WCF-Service. The byte[] is because of the Serialization.
        private byte[] GetReportDefinition()
        {
            ClaimListHeadDto head = new ClaimListHeadDto("this is the ClientAddress", "this is the DebtorAddres", "this is the IncidentNumber");
            List<ClaimListDto> claims = new List<ClaimListDto>
                                                    {
                                                        new ClaimListDto(new DateTime(2016, 01, 23), "Claim", 0, 0, null, new decimal(29.6f), null, null, null),
                                                        new ClaimListDto(new DateTime(2016, 01, 23), "Cost", 1, 0, null, null, new decimal(5.6f), null, null),
                                                        new ClaimListDto(new DateTime(2016, 02, 23), "Payment", 0, 0, new decimal(35.2f), null, null, null, null)
                                                    };

            claims.OrderBy(c => c.Date).ThenBy(c => c.RunningNumber);

            decimal? balance = null;

            foreach (ClaimListDto claim in claims)
            {
                if (claim.Type == 0)
                {
                    if (claim.ClaimAmount.HasValue)
                        balance -= claim.ClaimAmount.Value;

                    if (claim.CostAmount.HasValue)
                        balance -= claim.CostAmount.Value;

                    if (claim.RateAmount.HasValue)
                        balance -= claim.RateAmount.Value;
                }

                if (claim.Type == 1)
                    balance += claim.PaymentAmount.Value;

                claim.BalanceAmount = balance;
            }

            StiReport report = GetReport(head, claims);

            return report.SaveToByteArray();
        }

        private StiReport GetReport(ClaimListHeadDto head, List<ClaimListDto> claims)
        {
            return new ReportHelper(head, claims).GetReportById(1001);
        }

        private void SetDefaultReport(ref StiReport report)
        {
            report.Pages.Clear();

            report.NeedsCompiling = false;
            report.EngineVersion = StiEngineVersion.EngineV2;
            report.PreviewSettings = 268435455;
            report.ReferencedAssemblies = new string[]
                                                {
                                                    "Stimulsoft.Base.Dll",
                                                    "Stimulsoft.Controls.Dll",
                                                    "Stimulsoft.Report.Dll",
                                                    "System.Dll",
                                                    "System.Data.Dll",
                                                    "System.Drawing.Dll",
                                                    "System.Windows.Forms.Dll",
                                                    "System.Xml.Dll",
                                                    //"NotFilledDataBand.dll"
                                                    "Merkur.WPFReports.Dll"
                                                };
            report.ReportCreated = DateTime.Now;
            report.ReportGuid = new Guid().ToString();
            report.ReportUnit = StiReportUnitType.Centimeters;
            report.ReportVersion = "2016.3.0";
            report.ScriptLanguage = StiReportLanguageType.CSharp;
        }
    }
}
